@@ -1,6 +1,7 @@
 from abc import abstractmethod
 from abc import ABC
 import asyncio
+import logging
 from bergen.wards.base import GraphQLException, MainWard, TokenExpired
 import aiohttp
 import requests
@@ -11,6 +12,8 @@ from typing import TypeVar
 
 T = TypeVar("T")
 
+logger = logging.getLogger(__name__)
+
 
 class BareMainWard(MainWard):
 
@@ -27,15 +30,25 @@ class BareMainWard(MainWard):
         try:
             async with self.async_session.post(self._graphql_endpoint, json={"query": query_node, "variables": variables}) as resp:
 
+                if resp.status == 200:
+                    result = await resp.json() 
+                    logger.debug(f"Received Reply {result}")
+
+                    if "errors" in result:
+                        raise GraphQLException(f"Ward {self._graphql_endpoint}:" + str(result["errors"]))
+
+                    return the_query.extract(result["data"])
+
+                if resp.status == 400:
+                    raise WardException(await resp.json())
+
+
                 if resp.status == 403:
-                    raise TokenExpired("Token was Expired")
-            
-                result = await resp.json() 
+                    console.log("Auth token is expired trying to refresh")
+                    raise TokenExpired("Token Expired Error")
 
-                if "errors" in result:
-                    raise GraphQLException(f"Ward {self._graphql_endpoint}:" + str(result["errors"]))
 
-                return the_query.extract(result["data"])
+                raise WardException(f"Unexpected statuscode {resp.status} {resp}")
 
         except:
             console.print_exception(show_locals=True)
